@@ -27,7 +27,7 @@ as their content is relevant for command line use of the `refinery`.
 Furthermore, the module documentation of `refinery.units` contains a brief
 example of how to write simple units.
 """
-__version__ = '0.4.6'
+__version__ = '0.4.7'
 __pip_pkg__ = 'binary-refinery'
 
 from typing import Dict, Type
@@ -85,7 +85,7 @@ class _cache:
 
     def reload(self):
         if not self.reloading:
-            from .lib.loader import get_all_entry_points
+            from refinery.lib.loader import get_all_entry_points
             self.reloading = True
             self.units.clear()
             self.cache.clear()
